@@ -30,7 +30,7 @@ our @EXPORT = qw(xml_encode
 		 set_doctype_pubid
 		 );
 
-our $VERSION = '0.09';
+our $VERSION = '0.11';
 
 our $MAX_ITER = 20;
 
@@ -979,7 +979,7 @@ sub new {
     $iodef->{"DOM"} = $doc;
 
     $iodef->add("version", $IODEF_VERSION);
-    $iodef->add("xmlns:iodef", "urn:ietf:params:xml:ns:iodef-1.0");
+#    $iodef->add("xmlns:iodef", "urn:ietf:params:xml:ns:iodef-1.0");
     $iodef->add("xmlns:xsi","http://www.w3.org/2001/XMLSchema-instance");
     $iodef->add("xsi:schemaLocation","urn:ietf:params:xmls:schema:iodef-1.0");
 
@@ -1937,6 +1937,13 @@ sub to_hash {
 
     return $result;
 }
+
+# there's probably a 'better' way to do this wihtin DOM
+# but who has that kind of time with XML::Simple :)
+sub to_tree {
+    my $iodef = shift;
+    return(XMLin($iodef->out()));
+}
     
 
 #----------------------------------------------------------------------------------------
